@@ -3,7 +3,7 @@
 # Make sure that TDBC is running in a compatible version of Tcl, and
 # that TclOO is available.
 
-if {[catch {package present Tcl 8.5}]} {
+if {[catch {package present Tcl 8.5-}]} {
     return
 }
 apply {{dir} {
@@ -11,8 +11,8 @@ apply {{dir} {
     if {![file exists $libraryfile] && [info exists ::env(TDBC_LIBRARY)]} {
 	set libraryfile [file join $::env(TDBC_LIBRARY) tdbc.tcl]
     }
-    package ifneeded tdbc 1.1.0 \
-	"package require TclOO 0.6-;\
-	[list load [file join $dir libtdbc1.1.0.so] tdbc]\;\
+    package ifneeded tdbc 1.1.2 \
+	"package require TclOO 1.0-;\
+	[list load [file join $dir libtdbc1.1.2.so] tdbc]\;\
 	[list source $libraryfile]"
 }} $dir
